Stan Math Library: stan Namespace Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Namespaces | Classes | Functions
stan Namespace Reference

## Namespaces
| math
| Matrices and templated mathematical functions.

## Classes
struct | contains_fvar
| Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters. More...
struct | contains_nonconstant_struct
struct | contains_vector
struct | error_index
struct | is_constant
| Metaprogramming struct to detect whether a given type is constant in the mathematical sense (not the C++ `const` sense). More...
struct | is_constant_struct
| Metaprogram to determine if a type has a base scalar type that can be assigned to type double. More...
struct | is_constant_struct< Eigen::Block< T > >
struct | is_constant_struct< Eigen::Matrix< T, R, C > >
struct | is_constant_struct< std::vector< T > >
struct | is_fvar
struct | is_fvar< stan::math::fvar< T > >
struct | is_var
struct | is_var< stan::math::var >
struct | is_var_or_arithmetic
struct | is_vector
struct | is_vector< const T >
struct | is_vector< Eigen::Block< T > >
struct | is_vector< Eigen::Matrix< T, 1, Eigen::Dynamic > >
struct | is_vector< Eigen::Matrix< T, Eigen::Dynamic, 1 > >
struct | is_vector< std::vector< T > >
struct | is_vector_like
| Template metaprogram indicates whether a type is vector_like. More...
struct | is_vector_like< const T >
| Template metaprogram indicates whether a type is vector_like. More...
struct | is_vector_like< Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > >
| Template metaprogram indicates whether a type is vector_like. More...
struct | is_vector_like< T * >
| Template metaprogram indicates whether a type is vector_like. More...
struct | partials_return_type
struct | partials_type
struct | partials_type< stan::math::fvar< T > >
struct | partials_type< stan::math::var >
struct | return_type
| Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters. More...
struct | scalar_type
| Metaprogram structure to determine the base scalar type of a template argument. More...
struct | scalar_type< Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > >
struct | scalar_type< T * >
struct | scalar_type_pre
| Metaprogram structure to determine the type of first container of the base scalar type of a template argument. More...
struct | size_of_helper
struct | size_of_helper< T, true >
class | VectorBuilder
| VectorBuilder allocates type T1 values to be used as intermediate values. More...
class | VectorBuilderHelper
| VectorBuilder allocates type T1 values to be used as intermediate values. More...
class | VectorBuilderHelper< T1, true, false >
class | VectorBuilderHelper< T1, true, true >
| Template specialization for using a vector. More...
class | VectorView
| VectorView is a template expression that is constructed with a container or scalar, which it then allows to be used as an array using `operator[]`. More...
class | VectorView< const Eigen::Matrix< T, R, C >, true, false >
class | VectorView< const std::vector< T >, true, false >
class | VectorView< Eigen::Matrix< T, R, C >, true, false >
class | VectorView< std::vector< T >, true, false >
class | VectorView< T, false, false >
class | VectorView< T, is_array, true >
class | VectorView< T, true, false >
class | VectorViewMvt
class | VectorViewMvt< const T, is_array, throw_if_accessed >
| VectorViewMvt that has const correctness. More...

## Functions
template<typename T >
T | get (const std::vector< T > &x, size_t n)
template<typename T >
size_t | length (const std::vector< T > &x)
template<typename T , int R, int C>
T | get (const Eigen::Matrix< T, R, C > &m, size_t n)
template<typename T , int R, int C>
size_t | length (const Eigen::Matrix< T, R, C > &m)
template<typename T , int R, int C>
size_t | length_mvt (const Eigen::Matrix< T, R, C > &)
template<typename T , int R, int C>
size_t | length_mvt (const std::vector< Eigen::Matrix< T, R, C > > &x)
template<typename T >
T | get (const T &x, size_t n)
template<typename T >
size_t | length (const T &)
template<typename T >
size_t | length_mvt (const T &)
template<typename T1 , typename T2 >
size_t | max_size (const T1 &x1, const T2 &x2)
template<typename T1 , typename T2 , typename T3 >
size_t | max_size (const T1 &x1, const T2 &x2, const T3 &x3)
template<typename T1 , typename T2 , typename T3 , typename T4 >
size_t | max_size (const T1 &x1, const T2 &x2, const T3 &x3, const T4 &x4)
template<typename T1 , typename T2 >
size_t | max_size_mvt (const T1 &x1, const T2 &x2)
template<typename T1 , typename T2 , typename T3 >
size_t | max_size_mvt (const T1 &x1, const T2 &x2, const T3 &x3)
template<typename T1 , typename T2 , typename T3 , typename T4 >
size_t | max_size_mvt (const T1 &x1, const T2 &x2, const T3 &x3, const T4 &x4)
template<typename T >
size_t | size_of (const T &x)

## Function Documentation

template<typename T , int R, int C>

T stan::get | ( | const Eigen::Matrix< T, R, C > & | m,
|  | size_t | n
| ) |  |
| inline

Definition at line 9 of file get.hpp.

template<typename T >

T stan::get | ( | const std::vector< T > & | x,
|  | size_t | n
| ) |  |
| inline

Definition at line 10 of file get.hpp.

template<typename T >

T stan::get | ( | const T & | x,
|  | size_t | n
| ) |  |
| inline

Definition at line 10 of file get.hpp.

template<typename T , int R, int C>

size_t stan::length | ( | const Eigen::Matrix< T, R, C > & | m | ) |

Definition at line 9 of file length.hpp.

template<typename T >

size_t stan::length | ( | const T & |  | ) |

Definition at line 9 of file length.hpp.

template<typename T >

size_t stan::length | ( | const std::vector< T > & | x | ) |

Definition at line 10 of file length.hpp.

template<typename T >

size_t stan::length_mvt | ( | const T & |  | ) |

Definition at line 9 of file length_mvt.hpp.

template<typename T , int R, int C>

size_t stan::length_mvt | ( | const Eigen::Matrix< T, R, C > & |  | ) |

Definition at line 12 of file length_mvt.hpp.

template<typename T , int R, int C>

size_t stan::length_mvt | ( | const std::vector< Eigen::Matrix< T, R, C > > & | x | ) |

Definition at line 17 of file length_mvt.hpp.

template<typename T1 , typename T2 >

size_t stan::max_size | ( | const T1 & | x1,
|  | const T2 & | x2
| ) |  |

Definition at line 9 of file max_size.hpp.

template<typename T1 , typename T2 , typename T3 >

size_t stan::max_size | ( | const T1 & | x1,
|  | const T2 & | x2,
|  | const T3 & | x3
| ) |  |

Definition at line 16 of file max_size.hpp.

template<typename T1 , typename T2 , typename T3 , typename T4 >

size_t stan::max_size | ( | const T1 & | x1,
|  | const T2 & | x2,
|  | const T3 & | x3,
|  | const T4 & | x4
| ) |  |

Definition at line 24 of file max_size.hpp.

template<typename T1 , typename T2 >

size_t stan::max_size_mvt | ( | const T1 & | x1,
|  | const T2 & | x2
| ) |  |

Definition at line 10 of file max_size_mvt.hpp.

template<typename T1 , typename T2 , typename T3 >

size_t stan::max_size_mvt | ( | const T1 & | x1,
|  | const T2 & | x2,
|  | const T3 & | x3
| ) |  |

Definition at line 17 of file max_size_mvt.hpp.

template<typename T1 , typename T2 , typename T3 , typename T4 >

size_t stan::max_size_mvt | ( | const T1 & | x1,
|  | const T2 & | x2,
|  | const T3 & | x3,
|  | const T4 & | x4
| ) |  |

Definition at line 25 of file max_size_mvt.hpp.

template<typename T >

size_t stan::size_of | ( | const T & | x | ) |

Definition at line 24 of file size_of.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.